@@ -1,22 +1,21 @@
 from pytest import raises
 import sqlalchemy as sa
-from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy_i18n import Translatable, ImproperlyConfigured
+from sqlalchemy_i18n import (
+    Translatable, translation_base, ImproperlyConfigured
+)
 from tests import TestCase
 
 
 class TestPropertyCollision(TestCase):
+    configure_mappers = False
+    create_tables = False
+
     def create_models(self):
         class Article(self.Model, Translatable):
             __tablename__ = 'article'
-            __translated_columns__ = [
-                sa.Column('name', sa.Unicode(255))
-            ]
             __translatable__ = {
-                'base_classes': (self.Model, ),
                 'locales': ['fi', 'en'],
                 'auto_create_locales': True,
-                'default_locale': lambda self: self.locale or 'en'
             }
 
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
@@ -30,17 +29,10 @@ class TestPropertyCollision(TestCase):
 
         self.Article = Article
 
-    def setup_method(self, method):
-        self.engine = sa.create_engine(
-            'postgres://postgres@localhost/sqlalchemy_i18n_test'
-        )
-        self.Model = declarative_base()
-
-        self.create_models()
-
     def test_raises_exception(self):
         with raises(ImproperlyConfigured):
-            self.Article()
+            class ArticleTranslation(translation_base(self.Article)):
+                __tablename__ = 'article_translation'
 
-    def teardown_method(self, method):
-        self.engine.dispose()
+                name = sa.Column(sa.Unicode(255))
+            self.Article()
